# To-Dos (Administration)
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/to-dos-administration#introduction)
  * [Creating Approval To-Dos](https://help.sap.com/docs/leanix/ea/to-dos-administration#creating-approval-to-dos)
  * [Managing To-Dos](https://help.sap.com/docs/leanix/ea/to-dos-administration#managing-to-dos)
  * [Modifying To-Do Items](https://help.sap.com/docs/leanix/ea/to-dos-administration#modifying-to-do-items)


As an admin, learn how to create approval to-dos and manage all the to-do items in the administration area.
**Note**
This guide is for admin users and contains information on functions only they can perform. For general information about the to-do feature and how to use it, please refer [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD "To-dos facilitate task delegation, collaboration, and governance and can be used to ensure data integrity and quality through transparent task management.").
